@@ -35,45 +35,6 @@ class Shortcuts(object):
         
         self.setup_shortcuts()
 
-    def activate_latex_documents_mode(self):
-        self.set_accels_for_insert_before_after_action(['\\textbf{', '}'], ['<Control>b'])
-        self.set_accels_for_insert_before_after_action(['\\textit{', '}'], ['<Control>i'])
-        self.set_accels_for_insert_before_after_action(['\\underline{', '}'], ['<Control>u'])
-        self.set_accels_for_insert_before_after_action(['\\emph{', '}'], ['<Control><Shift>e'])
-        self.set_accels_for_insert_before_after_action(['\\texttt{', '}'], ['<Control>m'])
-        self.set_accels_for_insert_before_after_action(['$ ', ' $'], ['<Control><Shift>m'])
-        self.set_accels_for_insert_before_after_action(['\\[ ', ' \\]'], ['<Alt><Shift>m'])
-        self.set_accels_for_insert_before_after_action(['\\begin{equation}\n\t', '\n\\end{equation}'], ['<Control><Shift>n'])
-        self.set_accels_for_insert_before_after_action(['\\begin{•}\n\t', '\n\\end{•}'], ['<Control>e'])
-        self.set_accels_for_insert_before_after_action(['_{', '}'], ['<Control><Shift>d'])
-        self.set_accels_for_insert_before_after_action(['^{', '}'], ['<Control><Shift>u'])
-        self.set_accels_for_insert_before_after_action(['\\sqrt{', '}'], ['<Control><Shift>q'])
-        self.set_accels_for_insert_symbol_action(['\\frac{•}{•}'], ['<Alt><Shift>f'])
-        self.set_accels_for_insert_symbol_action(['\\left •'], ['<Control><Shift>l'])
-        self.set_accels_for_insert_symbol_action(['\\right •'], ['<Control><Shift>r'])
-        self.set_accels_for_insert_symbol_action(['\\item •'], ['<Control><Shift>i'])
-        self.set_accels_for_insert_symbol_action(['\\\\\n'], ['<Control>Return'])
-        self.main_window.app.set_accels_for_action('win.comment-uncomment', ['<Control>K'])
-
-    def activate_bibtex_documents_mode(self):
-        self.set_accels_for_insert_before_after_action(['\\textbf{', '}'], [])
-        self.set_accels_for_insert_before_after_action(['\\textit{', '}'], [])
-        self.set_accels_for_insert_before_after_action(['\\underline{', '}'], [])
-        self.set_accels_for_insert_before_after_action(['\\emph{', '}'], [])
-        self.set_accels_for_insert_before_after_action(['\\texttt{', '}'], [])
-        self.set_accels_for_insert_before_after_action(['$ ', ' $'], [])
-        self.set_accels_for_insert_before_after_action(['\\[ ', ' \\]'], [])
-        self.set_accels_for_insert_before_after_action(['\\begin{equation}\n\t', '\n\\end{equation}'], [])
-        self.set_accels_for_insert_before_after_action(['_{', '}'], [])
-        self.set_accels_for_insert_before_after_action(['^{', '}'], [])
-        self.set_accels_for_insert_before_after_action(['\\sqrt{', '}'], [])
-        self.set_accels_for_insert_symbol_action(['\\frac{•}{•}'], [])
-        self.set_accels_for_insert_symbol_action(['\\left •'], [])
-        self.set_accels_for_insert_symbol_action(['\\right •'], [])
-        self.set_accels_for_insert_symbol_action(['\\item •'], [])
-        self.set_accels_for_insert_symbol_action(['\\\\\n'], [])
-        self.main_window.app.set_accels_for_action('win.comment-uncomment', [])
-
     def set_accels_for_insert_before_after_action(self, parameter, accels):
         self.main_window.app.set_accels_for_action(Gio.Action.print_detailed_name('win.insert-before-after', GLib.Variant('as', parameter)), accels)
 
@@ -95,7 +56,6 @@ class Shortcuts(object):
         self.accel_group.connect(Gdk.keyval_from_name('n'), c_mask, flags, self.shortcut_new)
         self.accel_group.connect(Gdk.keyval_from_name('t'), c_mask, flags, self.shortcut_show_open_docs)
         self.accel_group.connect(Gdk.keyval_from_name('F1'), 0, flags, self.shortcut_help)
-        self.accel_group.connect(Gdk.keyval_from_name('F6'), 0, flags, self.shortcut_build)
         self.accel_group.connect(Gdk.keyval_from_name('F8'), 0, flags, self.shortcut_build_log)
         self.accel_group.connect(Gdk.keyval_from_name('F9'), 0, flags, self.shortcut_sidebar)
         self.accel_group.connect(Gdk.keyval_from_name('F10'), 0, flags, self.shortcut_preview)
@@ -111,6 +71,8 @@ class Shortcuts(object):
         self.main_window.app.set_accels_for_action('win.find-next', ['<Control>g'])
         self.main_window.app.set_accels_for_action('win.find-prev', ['<Control><Shift>g'])
         self.main_window.app.set_accels_for_action('win.find-replace', ['<Control>h'])
+        self.main_window.app.set_accels_for_action('win.save-and-build', ['F5'])
+        self.main_window.app.set_accels_for_action('win.build', ['F6'])
         self.main_window.app.set_accels_for_action('win.save', ['<Control>s'])
         self.main_window.app.set_accels_for_action('win.save-as', ['<Control><Shift>s'])
         self.main_window.app.set_accels_for_action('win.close-active-document', ['<Control>w'])
@@ -135,18 +97,6 @@ class Shortcuts(object):
         if self.main_window.headerbar.center_widget.center_button.get_sensitive():
             self.main_window.headerbar.center_widget.center_button.clicked()
 
-    def shortcut_build(self, accel_group=None, window=None, key=None, mask=None):
-        if self.workspace.get_active_document() != None:
-            if self.workspace.master_document != None:
-                document = self.workspace.master_document
-            else:
-                document = self.workspace.active_document
-            try:
-                document.build_widget.build_document_request()
-            except AttributeError:
-                pass
-        return True
-
     def shortcut_sidebar(self, accel_group=None, window=None, key=None, mask=None):
         toggle = self.main_window.headerbar.sidebar_toggle
         if toggle.get_sensitive():
@@ -166,7 +116,7 @@ class Shortcuts(object):
         return True
 
     def shortcut_build_log(self, accel_group=None, window=None, key=None, mask=None):
-        toggle = self.main_window.shortcuts_bar.button_build_log.get_child()
+        toggle = self.main_window.latex_shortcuts_bar.button_build_log.get_child()
         if toggle.get_sensitive():
             toggle.clicked()
         return True
@@ -177,6 +127,6 @@ class Shortcuts(object):
     def shortcut_quotes(self, accel_group=None, window=None, key=None, mask=None):
         active_document = self.workspace.get_active_document()
         if active_document != None and active_document.is_latex_document():
-            self.main_window.shortcuts_bar.quotes_button.set_active(True)
+            self.main_window.latex_shortcuts_bar.quotes_button.set_active(True)
 
 
