@@ -52,8 +52,8 @@ class WorkspaceController(object):
         self.main_window.sidebar.connect('size-allocate', self.on_sidebar_size_allocate)
         self.main_window.preview_help_stack.connect('size-allocate', self.on_preview_size_allocate)
         self.main_window.preview_paned.connect('size-allocate', self.on_preview_paned_size_allocate)
-        self.main_window.notebook_wrapper.connect('size-allocate', self.on_build_log_size_allocate)
-        self.main_window.shortcuts_bar.button_build_log.connect('clicked', self.on_build_log_button_clicked)
+        self.main_window.latex_notebook_wrapper.connect('size-allocate', self.on_build_log_size_allocate)
+        self.main_window.latex_shortcuts_bar.button_build_log.connect('clicked', self.on_build_log_button_clicked)
 
     def observe_document_chooser(self):
         document_chooser = self.main_window.headerbar.document_chooser
